@@ -497,6 +497,8 @@ fn get_logins<T: AsRef<Path>>(
     config_path: T,
     unlock_options: &Option<UnlockOptions>,
     get_mode: &Option<GetMode>,
+    advanced_fields: bool,
+    json: bool,
 ) -> Result<()> {
     let config = Config::read_from(config_path.as_ref())?;
     let _current_caller = verify_caller(&config)?;
@@ -584,7 +586,19 @@ fn get_logins<T: AsRef<Path>>(
         git_resp.password = Some(login.password.clone());
     }
 
-    io::stdout().write_all(git_resp.to_string().as_bytes())?;
+    if advanced_fields {
+        if let Some(ref login_entry_fields) = login.string_fields {
+            if !login_entry_fields.is_empty() {
+                git_resp.set_string_fields(login_entry_fields);
+            }
+        }
+    }
+
+    if json {
+        io::stdout().write_all(serde_json::to_string(&git_resp)?.as_bytes())?;
+    } else {
+        io::stdout().write_all(git_resp.to_string().as_bytes())?;
+    }
 
     Ok(())
 }
@@ -848,13 +862,33 @@ fn real_main() -> Result<()> {
         "totp" => Some(GetMode::TotpOnly),
         _ => None,
     };
+    let advanced_fields = match subcommand {
+        "get" => args
+            .subcommand_matches("get")
+            .map(|m| m.is_present("advanced-fields"))
+            .unwrap(),
+        _ => false,
+    };
+    let json = match subcommand {
+        "get" | "totp" => args
+            .subcommand_matches(subcommand)
+            .map(|m| m.is_present("json"))
+            .unwrap(),
+        _ => false,
+    };
     match subcommand {
         "configure" => configure(config_path, &args),
         "edit" => edit(config_path),
         "encrypt" => encrypt(config_path, &args),
         "decrypt" => decrypt(config_path),
         "caller" => caller(config_path, &args),
-        "get" | "totp" => get_logins(config_path, &unlock_options, &get_mode),
+        "get" | "totp" => get_logins(
+            config_path,
+            &unlock_options,
+            &get_mode,
+            advanced_fields,
+            json,
+        ),
         "store" => store_login(config_path, &unlock_options),
         "erase" => erase_login(),
         "lock" => lock_database(config_path),
